@@ -1,12 +1,13 @@
 import asyncio
 import logging
-from .tasks import create_task, create_task_with_factory
+from .tasks import create_task, TaskFactory
 from .uv import UVLoop
 
 import asyncio
 import platform
 
-is_pypy = platform.python_implementation() == 'PyPy'
+is_pypy = platform.python_implementation() == "PyPy"
+
 async def task_wrapper(exception_handler, loop, response, task):
     try:
         return await task
@@ -25,13 +26,13 @@ async def task_wrapper(exception_handler, loop, response, task):
 
 class Loop:
     def __init__(self, exception_handler=None, task_factory_max_items=0):
-        
+
         # get the current running loop or create a new one without warnings
         self.loop = asyncio._get_running_loop()
         if self.loop is None:
             self.loop = asyncio.new_event_loop()
             asyncio.set_event_loop(self.loop)
-            
+
         self.uv_loop = UVLoop()
 
         if hasattr(exception_handler, "__call__"):
@@ -43,23 +44,20 @@ class Loop:
             self.exception_handler = None
 
         self.started = False
-        if is_pypy: # PyPy async Optimizations
-            if task_factory_max_items > 0: # Only available in PyPy for now
-                self._task_factory = create_task_with_factory(task_factory_max_items)
+        if is_pypy:  # PyPy async Optimizations
+            if task_factory_max_items > 0:  # Only available in PyPy for now
+                self._task_factory = TaskFactory(task_factory_max_items)
             else:
                 self._task_factory = create_task
             self.run_async = self._run_async_pypy
             # custom task factory
             def pypy_task_factory(loop, coro, context=None):
                 return create_task(loop, coro, context=context)
+
             self.loop.set_task_factory(pypy_task_factory)
         else:
-            # CPython performs worse using custom create_task, so native create_task is used
-            # but this also did not allow the use of create_task_with_factory :/
-            # native create_task do not allow to change context, callbacks, state etc
-            
+            # CPython performs equals or worse using TaskFactory
             self.run_async = self._run_async_cpython
-        
 
     def set_timeout(self, timeout, callback, user_data):
         return self.uv_loop.create_timer(timeout, 0, callback, user_data)
@@ -71,7 +69,7 @@ class Loop:
         if self.started:
             self.uv_loop.run_once()
             self.loop.call_soon(self._keep_alive)
-   
+
     def create_task(self, *args, **kwargs):
         # this is not using optimized create_task yet
         return self.loop.create_task(*args, **kwargs)
@@ -84,7 +82,7 @@ class Loop:
         if task is not None:
             future = self.ensure_future(task)
         else:
-            future = None    
+            future = None
         self.loop.call_soon(self._keep_alive)
         self.loop.run_until_complete(future)
         # clean up uvloop
@@ -96,7 +94,7 @@ class Loop:
         if task is not None:
             future = self.ensure_future(task)
         else:
-            future = None    
+            future = None
         self.loop.call_soon(self._keep_alive)
         self.loop.run_forever()
         # clean up uvloop
@@ -104,13 +102,12 @@ class Loop:
         return future
 
     def run_once(self):
-        # run one step of asyncio 
+        # run one step of asyncio
         self.loop._stopping = True
         self.loop._run_once()
         # run one step of libuv
         self.uv_loop.run_once()
 
-        
     def stop(self):
         if self.started:
             # Just mark as started = False and wait
@@ -120,29 +117,29 @@ class Loop:
     # Exposes native loop for uWS
     def get_native_loop(self):
         return self.uv_loop.get_native_loop()
-   
 
     def _run_async_pypy(self, task, response=None):
         # this garanties error 500 in case of uncaught exceptions, and can trigger the custom error handler
-        # using an coroutine wrapper generates less overhead than using add_done_callback 
-        # this is an custom task/future with less overhead
-        future = self._task_factory(self.loop, task_wrapper(self.exception_handler, self.loop, response, task))
-        # force asyncio run once to enable req in async functions before first await
-        self.loop._run_once()
-        return None # this future maybe already done and reused not safe to await
+        # using an coroutine wrapper generates less overhead than using add_done_callback
+        # this is an custom task/future with less overhead and that calls the first step
+        future = self._task_factory(
+            self.loop, task_wrapper(self.exception_handler, self.loop, response, task)
+        )
+        return None  # this future maybe already done and reused not safe to await
 
-    def _run_async_cpython(self, task, response=None):       
+    def _run_async_cpython(self, task, response=None):
         # this garanties error 500 in case of uncaught exceptions, and can trigger the custom error handler
-        # using an coroutine wrapper generates less overhead than using add_done_callback 
-        future = self.loop.create_task(task_wrapper(self.exception_handler, self.loop, response, task))
-        # force asyncio run once to enable req in async functions before first await
-        self.loop._run_once()
-        return None # this future is safe to await but we return None for compatibility, and in the future will be the same behavior as PyPy
+        # using an coroutine wrapper generates less overhead than using add_done_callback
+        # this is an custom task/future with less overhead and that calls the first step
+        future = create_task(self.loop, task_wrapper(self.exception_handler, self.loop, response, task))
+        return None  # this future is safe to await but we return None for compatibility, and in the future will be the same behavior as PyPy
+
     def dispose(self):
         if self.uv_loop:
             self.uv_loop.dispose()
             self.uv_loop = None
 
+
 #  if sys.version_info >= (3, 11)
 #         with asyncio.Runner(loop_factory=uvloop.new_event_loop) as runner:
 #             runner.run(main())
