@@ -89,7 +89,9 @@ class RequestTask:
     # status is still pending
     _log_destroy_pending = True
 
-    def __init__(self, coro, loop, default_done_callback=None, no_register=False, context=None):
+    def __init__(
+        self, coro, loop, default_done_callback=None, no_register=False, context=None
+    ):
         """Initialize the future.
 
         The optional event_loop argument allows explicitly setting the event
@@ -113,7 +115,8 @@ class RequestTask:
             self._log_destroy_pending = False
             if self._loop.get_debug():
                 self._source_traceback = format_helpers.extract_stack(sys._getframe(1))
-            self._loop.call_soon(self.__step, context=self._context)
+            # self._loop.call_soon(self.__step, context=self._context)
+            self.__step()
             _register_task(self)
 
     def _reuse(self, coro, loop, default_done_callback=None):
@@ -145,7 +148,8 @@ class RequestTask:
         self._fut_waiter = None
         self._coro = coro
 
-        self._loop.call_soon(self.__step, context=self._context)
+        # self._loop.call_soon(self.__step, context=self._context)
+        self.__step()
         _register_task(self)
 
     def __repr__(self):
@@ -578,27 +582,52 @@ class RequestTask:
     __iter__ = __await__  # make compatible with 'yield from'.
 
 
-def create_task_with_factory(task_factory_max_items=100_000):
-    items = []
-    for _ in range(0, task_factory_max_items):
-        task = RequestTask(None, None, None, True)
-        if task._source_traceback:
-            del task._source_traceback[-1]
-        items.append(task)
+# def create_task_with_factory(task_factory_max_items=100_000):
+#     items = []
+#     for _ in range(0, task_factory_max_items):
+#         task = RequestTask(None, None, None, True)
+#         if task._source_traceback:
+#             del task._source_traceback[-1]
+#         items.append(task)
 
-    def factory(loop, coro, default_done_callback=None):
-        if len(items) == 0:
-            return create_task(loop, coro, default_done_callback)
-        task = items.pop()
-        def done(f):
-            if default_done_callback is not None:
-                default_done_callback(f)    
-            items.append(f)
-        task._reuse(coro, loop, done)
+#     def factory(loop, coro, default_done_callback=None):
+#         if len(items) == 0:
+#             return create_task(loop, coro, default_done_callback)
+#         task = items.pop()
+
+#         def done(f):
+#             if default_done_callback is not None:
+#                 default_done_callback(f)
+#             items.append(f)
+
+#         task._reuse(coro, loop, done)
+#         return task
+
+#     return factory
+
+async def factory_task_wrapper(task, dispose):
+    try:
+        await task
+    finally:
+        dispose()
+
+class TaskFactory:
+    def __init__(self, task_factory_max_items=100_000):
+        self.items = []
+        for _ in range(0, task_factory_max_items):
+            task = RequestTask(None, None, None, True)
+            if task._source_traceback:
+                del task._source_traceback[-1]
+            self.items.append(task)
+
+    def __call__(self, loop, coro):
+        if len(self.items) == 0:
+            return create_task(loop, coro)
+        task = self.items.pop()
+
+        task._reuse(factory_task_wrapper(coro, lambda : self.items.append(task)), loop)
         return task
 
-    return factory
-
 
 def create_task(loop, coro, default_done_callback=None, context=None):
     """Schedule a coroutine object.
